# coding: utf-8

"""
    Standard Bots RO1 Robotics API

    Standard Bots RO1 Robotics API.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@standardbots.com
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "standardbots"
VERSION = "2.20250923.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "setuptools >= 21.0.0",
    "typing_extensions >= 4.3.0",
    "urllib3 >= 1.26.7",
]

setup(
    name=NAME,
    version=VERSION,
    description="Standard Bots RO1 Robotics API",
    author="Standard Bots Support",
    author_email="support@standardbots.com",
    url="",
    keywords=["Standard Bots RO1 Robotics API"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    Standard Bots RO1 Robotics API.  # noqa: E501
    """
)
